@@ -16,7 +16,7 @@ import argparse
 from sniffles import util
 
 VERSION="Sniffles2"
-BUILD="2.0.1"
+BUILD="2.0.3"
 SNF_VERSION="S2_rc3"
 
 class ArgFormatter(argparse.ArgumentDefaultsHelpFormatter, argparse.RawDescriptionHelpFormatter):
@@ -35,31 +35,31 @@ def tobool(v):
 def from_cmdline():
     header=f"Sniffles2: A fast structural variant (SV) caller for long-read sequencing data\n Version {BUILD}\n Contact: moritz.g.smolka@gmail.com"
     example=""" Usage example A - Call SVs for a single sample:
-    sniffles2 --input sorted_indexed_alignments.bam --vcf output.vcf
+    sniffles --input sorted_indexed_alignments.bam --vcf output.vcf
 
     ... OR, with CRAM input and bgzipped+tabix indexed VCF output:
-      sniffles2 --input sample.cram --vcf output.vcf.gz
+      sniffles --input sample.cram --vcf output.vcf.gz
 
     ... OR, producing only a SNF file with SV candidates for later multi-sample calling:
-      sniffles2 --input sample1.bam --snf sample1.snf
+      sniffles --input sample1.bam --snf sample1.snf
 
     ... OR, simultaneously producing a single-sample VCF and SNF file for later multi-sample calling:
-      sniffles2 --input sample1.bam --vcf sample1.vcf.gz --snf sample1.snf
+      sniffles --input sample1.bam --vcf sample1.vcf.gz --snf sample1.snf
 
     ... OR, with additional options to specify tandem repeat annotations (for improved call accuracy), reference (for DEL sequences) and non-germline mode for detecting rare SVs:
-      sniffles2 --input sample1.bam --vcf sample1.vcf.gz --tandem-repeats tandem_repeats.bed --reference genome.fa --non-germline
+      sniffles --input sample1.bam --vcf sample1.vcf.gz --tandem-repeats tandem_repeats.bed --reference genome.fa --non-germline
 
  Usage example B - Multi-sample calling:
-    Step 1. Create .snf for each sample: sniffles2 --input sample1.bam --snf sample1.snf
-    Step 2. Combined calling: sniffles2 --input sample1.snf sample2.snf ... sampleN.snf --vcf multisample.vcf
+    Step 1. Create .snf for each sample: sniffles --input sample1.bam --snf sample1.snf
+    Step 2. Combined calling: sniffles --input sample1.snf sample2.snf ... sampleN.snf --vcf multisample.vcf
 
     ... OR, using a .tsv file containing a list of .snf files, and custom sample ids in an optional second column (one sample per line):
-    Step 2. Combined calling: sniffles2 --input snf_files_list.tsv --vcf multisample.vcf
+    Step 2. Combined calling: sniffles --input snf_files_list.tsv --vcf multisample.vcf
 
  Usage example C - Determine genotypes for a set of known SVs (force calling):
-    sniffles2 --input sample.bam --genotype-vcf input_known_svs.vcf --vcf output_genotypes.vcf
+    sniffles --input sample.bam --genotype-vcf input_known_svs.vcf --vcf output_genotypes.vcf
     """
-    usage="sniffles2 --input SORTED_INPUT.bam [--vcf OUTPUT.vcf] [--snf MERGEABLE_OUTPUT.snf] [--threads 4] [--non-germline]\n\n" + header + "\n\n" + example + "\n\n Use --help for full parameter/usage information\n \n"
+    usage="sniffles --input SORTED_INPUT.bam [--vcf OUTPUT.vcf] [--snf MERGEABLE_OUTPUT.snf] [--threads 4] [--non-germline]\n\n" + header + "\n\n" + example + "\n\n Use --help for full parameter/usage information\n \n"
     parser = argparse.ArgumentParser(description="", epilog=example, formatter_class=lambda prog: ArgFormatter(prog,max_help_position=100,width=150), usage=usage)
     parser.add_argument("--version", action="version", version=f"Sniffles2, Version {BUILD}")
 
@@ -116,7 +116,8 @@ def from_cmdline():
     multi_args.add_argument("--combine-low-confidence", metavar="F", type=float, help="Minimum fraction of samples in which a SV needs to be present (failed QC) for it to be reported in combined output", default=0.2)
     multi_args.add_argument("--combine-low-confidence-abs", metavar="N", type=int, help="Minimum absolute number of samples in which a SV needs to be present (failed QC) for it to be reported in combined output", default=3)
     multi_args.add_argument("--combine-null-min-coverage", metavar="N", type=int, help="Minimum coverage for a sample genotype to be reported as 0/0 (sample genotypes with coverage below this threshold at the SV location will be output as ./.)", default=5)
-    multi_args.add_argument("--combine-match", metavar="N", type=int, help="Maximum deviation of multiple SV's start/end position for them to be combined across samples. Given by max_dev=M*sqrt(min(SV_length_a,SV_length_b)), where M is this parameter.", default=500)
+    multi_args.add_argument("--combine-match", metavar="N", type=int, help="Multiplier for maximum deviation of multiple SV's start/end position for them to be combined across samples. Given by max_dev=M*sqrt(min(SV_length_a,SV_length_b)), where M is this parameter.", default=250)
+    multi_args.add_argument("--combine-match-max", metavar="N", type=int, help="Upper limit for the maximum deviation computed for --combine-match, in bp.", default=1000)
     multi_args.add_argument("--combine-consensus", help="Output the consensus genotype of all samples", default=False, action="store_true")
     multi_args.add_argument("--combine-separate-intra", help="Disable combination of SVs within the same sample", default=False, action="store_true")
     multi_args.add_argument("--combine-output-filtered", help="Include low-confidence / putative non-germline SVs in multi-calling", default=False, action="store_true")
@@ -130,7 +131,7 @@ def from_cmdline():
     postprocess_args.add_argument("--no-sort", help="Do not sort output VCF by genomic coordinates (may slightly improve performance)", default=False, action="store_true")
     postprocess_args.add_argument("--no-progress", help="Disable progress display", default=False, action="store_true")
     postprocess_args.add_argument("--quiet", help="Disable all logging, except errors", default=False, action="store_true")
-    postprocess_args.add_argument("--max-del-seq-len", metavar="N", type=str, help="Maximum deletion sequence length to be output. Deletion SVs longer than this value will be written to the output as symbolic SVs.", default=50000)
+    postprocess_args.add_argument("--max-del-seq-len", metavar="N", type=int, help="Maximum deletion sequence length to be output. Deletion SVs longer than this value will be written to the output as symbolic SVs.", default=50000)
     postprocess_args.add_argument("--symbolic", help="Output all SVs as symbolic, including insertions and deletions, instead of reporting nucleotide sequences.", default=False, action="store_true")
 
     developer_args = parser.add_argument_group("Developer parameters")
